.\" -*-nroff-*-
.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "0.06",
.\"     date            = "18 June 2011",
.\"     time            = "15:16:11 MDT",
.\"     filename        = "cattobib.min",
.\"     address         = "University of Utah
.\"                        Department of Mathematics, 110 LCB
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "59843 727 3487 27659",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@computer.org (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "bibliography; BibTeX; Z39.50 catalog lookup",
.\"     license         = "GNU General Public License",
.\"     supported       = "yes",
.\"     docstring       = "This file contains the UNIX manual pages
.\"                        for the cattobib utility, a program for
.\"                        converting Z39.50 library catalog server
.\"                        data to BibTeX markup.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.if t .ds Bi B\s-2IB\s+2T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Bi BibTeX
.if t .ds Te T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Te TeX
.TH CATTOBIB 1 "18 June 2011" "Version 0.06"
.\" ====================================================================
.SH NAME
cattobib \- convert Z39.50 library catalog server data to BibTeX markup
.\" ====================================================================
.SH SYNOPSIS
.B cattobib
.RB [ \-? ]
.RB [ \-author ]
.RB [ \-by\fIxxx\fP ]
.RB [ \-CODEN ]
.RB [ \-debug ]
.RB [ \-editor ]
.RB [ \-help ]
.if n .ti +9n
.RB [ \-ISBN ]
.RB [ \-ISSN ]
.RB [ \-ISSN-L ]
.RB [ \-keep-files ]
.if t .ti +\w'\fBcattobib\fP\ 'u
.RB [ \-logfile ]
.RB [ \-quiet ]
.if n .ti +9n
.RB [ \-server " \fIname-or-path\fP" ]
.RB [ \-test ]
.RB [ \-title ]
.RB [ \-version ]
.if n .ti +9n
.if t .ti +\w'\fBcattobib\fP\ 'u
.RB [ \-volume ]
.if n .ti +9n
.if t .ti +\w'\fBcattobib\fP\ 'u
.I search-key-1
.I search-key-2
.I search-key-3
.I \|.\|.\|.
.if n .ti +9n
.RI > \*(Bi\&-file
.PP
.\" ====================================================================
.SH DESCRIPTION
.B cattobib
converts Z39.50 library-catalog server data to \*(Bi\& markup, using
one or more search keys provided on the command line. This allows
convenient re-use of publication data, and eases the tedious and
error-prone task of creating \*(Bi\& entries for books and other
cataloged publications.
.PP
The library catalog server can be specified by a command-line option,
with the default server being the world's largest library catalog, the
US Library of Congress.
.PP
ANSI/NISO Standard Z39.50-1995 and ISO Standard 23950:1998
``Information and documentation \(em Information retrieval (Z39.50)
\(em Application service definition and protocol specification''
define a library catalog protocol that allows client programs to
communicate with library catalog servers around the world, and
retrieve data in a small number of different formats, notably USMARC
.RI ( "United States MAchine-Readable Cataloging" )
and SUTRS
.RI ( "Simple Unstructured Text Record Syntax" ).
.\" ====================================================================
.SH OPTIONS
Command-line options may be abbreviated to a unique leading prefix,
and may begin with either one or two leading hyphens.  Uppercase
options may also be spelled in lowercase.
.\"---------------------------------------------------------------------
.\" .TP \w'\fB\-keep-files\fP'+2n
.TP
.B \-?
Give a brief help message on
.IR stdout ,
and exit immediately with a successful status code.
.\"---------------------------------------------------------------------
.TP
.BI \-author
Restrict search-key matching to author fields.
.\"---------------------------------------------------------------------
.TP
.BI \-by xxx
Pass this sort-order option to
.BR bibsort (1).
The suffix
.I xxx
is one of
.IR day ,
.IR label ,
.IR number ,
.IR pages ,
.IR seriesvolume ,
.IR volume ,
or
.IR year ,
or any other suffix supported by future versions of that program.
.\"---------------------------------------------------------------------
.TP
.BI \-CODEN
Restrict search-key matching to CODEN (Chemical Abstracts periodical
number) fields.
.\"---------------------------------------------------------------------
.TP
.BI \-debug
Display on
.I stderr
the commands to be sent to each Z39.50 catalog server immediately
before contacting that server.  Display the server session as well
on
.I stderr
when possible, and otherwise, log it to a temporary file whose name is
reported on
.IR stdout .
.\"---------------------------------------------------------------------
.TP
.BI \-editor
Restrict search-key matching to editor fields.
.\"---------------------------------------------------------------------
.TP
.B \-help
Give a help message on
.I stdout
describing the options and known Z39.50 servers, and exit immediately
with a successful status code.
.\"---------------------------------------------------------------------
.TP
.BI \-ISBN
Restrict search-key matching to ISBN (International Standard Book
Number) fields.
.IP
Because of its frequency of use, this option may be abbreviated to a
single letter, even though it shares a two-character prefix with
another option.
.\"---------------------------------------------------------------------
.TP
.BI \-ISSN
Restrict search-key matching to ISSN (International Standard Serial
Number) fields.
.\"---------------------------------------------------------------------
.TP
.BI \-ISSN-L
Restrict search-key matching to ISSN-L (linking International Standard
Serial Number) fields.
.\"---------------------------------------------------------------------
.TP
.B \-keep-files
Preserve intermediate scratch files in
.I /tmp
(or wherever the environment variable
.I TMPDIR
points).  They are named
.I cattobib.bib.nnn
(raw \*(Bi\& data before several cleanup steps),
.I cattobib.fifo.nnn
(raw data from Z39.50 server for the last item searched),
and
.IR cattobib.label.nnn
(citation-label substitution file),
where
.I nnn
is the process number.  Normally, these files are not of interest and
are deleted on exit, unless this option is specified.
.\"---------------------------------------------------------------------
.TP
.BI \-logfile " filename"
Log the output on the specified filename, which must be a new file,
instead of on
.IR stdout .
.\"---------------------------------------------------------------------
.TP
.B \-quiet
Suppress search status messages.
.\"---------------------------------------------------------------------
.TP
.BI \-server " names-or-paths"
Specify a list of one or Z39.50 catalog servers.  The
.I names-or-paths
value is either a space-separated list of paths to particular Z39.50
servers, usually in the form
.IR hostname:portnumber/databasename ,
or abbreviations for such servers, as shown below.  A
regularly-updated directory of Z39.50 servers can be found on the Web
at
.RS
.RS
\&\s-2\fChttp://www.indexdata.dk/targettest/\fP\s+2
.RE
.RE
.IP
This option can be specified as many times as needed, and all
specified servers are accumulated into a master list that is searched
on completion of command-line processing.
.IP
The special server name
.I home
means
.I all
of the aliases in the user-specific file
.IR $HOME/.cattobib.rc .
Similarly, the special server name
.I local
means
.I all
of the aliases in the local system-wide file
.IR /usr/local/share/cattobib/cattobib-0.06/cattobib.rc .
Any of the aliases in those files can also be used individually in the
.B \-server
option.
.IP
In this list, vertical bars separate alternatives, and asterisk
matches any word with that prefix:
.RS
.nf
\&\fC\s-2
ALL | A*                All Z39.50 servers known to cattobib
NATIONAL | N*           National libraries and union catalogs
alberta | ab            University of Alberta
amherst | umass         University of Massachusetts, Amherst
amicus | ca             National Library of Canada
anu                     Australian National University
be | ulb                Universit Libre de Bruxelles, Belgium
bibsys                  Norwegian Union Catalog
bne | es                National Library of Spain
bnp | pt                National Library of Portugal
boulder | co            University of Colorado, Boulder
british | br            British Library
byu                     Brigham Young University
calgary                 University of Calgary
caltech                 California Institute of Technology
carnegie | cmu          Carnegie Mellon University
chicago                 University of Chicago
columbia | cu           Columbia University
congress | lc | loc     US Library of Congress
copac | uk              COPAC (union of 24 research-university
                        catalogs in the UK and Ireland)
cosmos                  Danish National Library of Science & Medicine
crl                     Center for Research Libraries
dartmouth               Dartmouth College, NH
denmark | dk            Royal Library of Denmark
dsb | dsl               Danish State Library
duke                    Duke University
edinburgh | ed          Edinburgh University
emory                   Emory University
eu                      European University Institute Library
florida | fl            Florida Center for Library Automation
gbv                     German Union Catalog
gmu                     George Mason University
harvard                 Harvard University
hopkins | jhu           The Johns Hopkins University
indiana | iu            Indiana University
indystate | in          Indiana State University Consortium
kings | kcl             King's College (London)
ku-leuven | ku          Katholieke Universiteit Leuven, Belgium
madrid                  Universidad Autonoma de Madrid, Spain
marriott | utah | ut    University of Utah Marriott Library
mcgill                  McGill University
melbourne               University of Melbourne
melvyl | cal            University of California
michigan | mi           University of Michigan
minn* | mn              University of Minnesota
mit                     Massachusetts Institute of Technology
montreal | um           Universit de Montral
nbi | bohr              Niels Bohr Institut
newyork | ny            New York University
nla | au                National Library of Australia
nlm | nih               National Library of Medicine (US)
nlnz | nz               National Library of New Zealand
nls | scotland          National Library of Scotland
nlw | cwm | wales       National Library of Wales
northwestern | nw       Northwestern University
norway | no             National Library of Norway
nsw | unsw              University of New South Wales
nus | sg                National University of Singapore
odense | sdu            University of Southern Denmark
oregon | uo             University of Oregon
oxford | ox*            Oxford University
pennstate | psu | pa    Pennsylvania State University
poland | pl             National Library of Poland
princeton               Princeton University
quebec | uq             Universit de Qubec
rlg                     Research Libraries Group
rutgers                 Rutgers University
sfu                     Simon Fraser University
sudoc | abes | fr       French Union Catalog
sweden | se             National Library of Sweden
stanford | su           Stanford University
stockholm               Stockholm University
tamu                    Texas A&M University
texas | tx              University of Texas at Austin
toronto                 University of Toronto
trinity | tcd           Trinity College, Dublin
tub | berlin            Technische Universitt Berlin, Germany
tud | darmstadt         Technische Universitt Darmstadt, Germany
tufts                   Tufts University
ub | bern               Universitt Bern, Switzerland
ucc | cork              University College Cork, Ireland
ucd | dublin            University College Dublin, Ireland
ucsf                    University of California, San Francisco
upenn | penn            University of Pennsylvania
usc                     University of Southern California
uta                     University of Texas, Arlington
uwo                     University of Western Ontario
vanderbilt              Vanderbilt University
victoria | vu           Victoria University, Melbourne, Australia
westpoint | usma        United States Military Academy West Point
witwatersrand | wit     University of Witwatersrand, Johannesburg, South Africa
wustl                   Washington University St. Louis
yale                    Yale University\s+2\fP
.fi
.RE
.IP
A later section provides information about representing accented
characters in searches of the catalog of the National Library of
Poland.
.\"---------------------------------------------------------------------
.TP
.B \-test
Run in test mode: library-catalog data is supplied on
.IR stdin ,
instead of being fetched from a Z39.50 catalog server.  This option is
primarily intended for the installation-time validation test suite,
but can be also use for local testing and tuning of the
format-conversion software.
.\"---------------------------------------------------------------------
.TP
.BI \-title
Restrict search-key matching to title fields.
.\"---------------------------------------------------------------------
.TP
.B \-version
Display the version number and revision date on
.IR stdout ,
and exit immediately with a successful status code.
.IP
The option name may be abbreviated to a single letter.
.\"---------------------------------------------------------------------
.TP
.B \-volume
Search for a series and volume, where the search key consists of a
series name and a volume number, separated by one or more
nonalphanumeric, nonhyphen, nonspace characters.
.\" ====================================================================
.SH EXAMPLES
.B "Search the default Z39.50 server for a book by its ISBN:"
.nf
\&\s-2\fC% cattobib 1-57586-011-2
%% Searching [z3950.loc.gov:7090/Voyager] for [1575860112]: flags = [@attr 1=7]
@Book{Knuth:1999:DT,
  author =       "Donald Ervin Knuth",
  title =        "Digital typography",
  volume =       "78",
  publisher =    "CSLI Publications",
  address =      "Stanford, Calif.",
  pages =        "xv + 685",
  year =         "1999",
  ISBN =         "1-57586-011-2 (cloth), 1-57586-010-4 (paperback)",
  ISBN-13 =      "978-1-57586-011-4 (cloth), 978-1-57586-010-7 (paperback)",
  LCCN =         "Z249.3 .K59 1999",
  bibdate =      "Wed Jun 22 18:49:36 2005",
  bibsource =    "z3950.loc.gov:7090/Voyager",
  series =       "CSLI lecture notes",
  URL =          "ftp://uiarchive.cso.uiuc.edu/pub/etext/gutenberg/;
                 http://www.loc.gov/catdir/description/cam029/98027331.html;
                 http://www.loc.gov/catdir/toc/cam022/98027331.html",
  acknowledgement = ack-nhfb,
  subject =      "Printing; Data processing; Computerized typesetting;
                 Computer fonts; TeX (Computer file); METAFONT",
}\fP\s+2
.fi
.PP
.BR Remark :
The ISBN is a
.I unique
identifier assigned to books published throughout the world since
about 1972.  It consists of ten decimal digits, the last of which may
also be the letter X, divided into four hyphen- (or rarely, space-)
separated parts: country or language, publisher, book number within
the publisher, and a final check digit that can be used to detect
invalid ISBNs.
.PP
Country/language groups 0 and 1 are English, 2 is French, 3 is German,
4 is Japanese, 5 is Russian, and so on.  The Republic of Srpska (1996
population about 1.4 million people) is 99938.
.PP
Large publishers have small numbers (e.g., Collins is 00, McGraw-Hill
is 07, and Prentice-Hall is 13), and small publishers have big numbers
(e.g., Peachpit Press is 938151 and Personal \*(Te\& is 9631044).
.PP
When a publisher exhausts its range of book numbers, it gets a new
publisher number: for example, O'Reilly Media Inc. is assigned
publisher numbers 937175, 56592, and 596.
.PP
Because the 10-digit ISBN numbers are rapidly being exhausted,
effective 1-Jan-2007, they will no longer be issued, and instead are
to be replaced by new 13-digit values based on the
.I "European Article Numbering"
(EAN) system.  The name for the new system is ISBN-13, and such values
are also EAN values.
.PP
From version 0.02,
.B cattobib
output includes both ISBN(-10) and ISBN-13 data, since the latter are
beginning to appear in some online bookstore and library catalogs, and
some publishers now print them both with the back-cover bar code.
.PP
ISBN-13 translations of ISBN-10 data are handled automatically by
the
.BR biborder (1)
utility, and consist of the prefix \fC978-\fP followed by the first 9
digits of the ISBN-10 value with the same (optional) hyphenation as
before, followed by a hyphen and a new check digit.  The latter is
computed by a different algorithm, and will not in general match the
tenth digit (the check digit) of the ISBN-10 value.
.PP
.B "Search the default Z39.50 server for a book by its title:"
.nf
\&\s-2\fC% cattobib --title 'Digital Typography Sourcebook'
%% Searching [z3950.loc.gov:7090/Voyager] for [Digital Typography Sourcebook]: flags = []
@Book{Bryan:1996:DTS,
  author =       "Marvin Bryan",
  title =        "The digital typography sourcebook",
  publisher =    "Wiley",
  address =      "New York",
  pages =        "xxiv + 384, 3",
  year =         "1996",
  ISBN =         "0-471-14811-3 (paper/CD-ROM)",
  ISBN-13 =      "978-0-471-14811-1",
  LCCN =         "Z250.7 .B79 1996",
  bibdate =      "Wed Jun 22 18:49:36 2005",
  bibsource =    "z3950.loc.gov:7090/Voyager",
  URL =          "ftp://uiarchive.cso.uiuc.edu/pub/etext/gutenberg/;
                 http://www.loc.gov/catdir/bios/wiley047/96013161.html;
                 http://www.loc.gov/catdir/description/wiley033/96013161.html;
                 http://www.loc.gov/catdir/toc/onix04/96013161.html",
  acknowledgement = ack-nhfb,
  subject =      "Computer fonts",
}\fP\s+2
.fi
.PP
.B "Search the British Library for the same book:"
.nf
\&\s-2\fC% cattobib --server br --title 'Digital Typography Sourcebook'
%% Searching [z3950cat.bl.uk:9909/BLAC] for [Digital Typography Sourcebook]: flags = []
%% IGNORED:  Number of hits: 1, setno 1
\&\|.\|.\|.
@Book{Bryan:1997:DTS,
  author =       "Marvin Bryan",
  title =        "The digital typography sourcebook",
  publisher =    "Wiley",
  address =      "New York ; Chichester",
  pages =        "xxiv + 384",
  year =         "1997",
  ISBN =         "0-471-14811-3 (paperback)",
  ISBN-13 =      "978-0-471-14811-1",
  bibdate =      "Wed Jun 22 18:49:36 2005",
  acknowledgement = ack-nhfb,
  subject =      "Computer fonts",
}\fP\s+2
.fi
.PP
.B "Search the National Library of Australia for two books by ISBN:"
.nf
\&\s-2\fC% cattobib -q --server au --ISBN 0-06-621285-5 0-19-860702-4
@Book{Winchester:2003:KDW,
  author =       "Simon Winchester",
  title =        "Krakatoa: the day the world exploded, 27 August 1883",
  publisher =    "HarperCollins Publishers",
  address =      "New York",
  pages =        "xvi + 416",
  year =         "2003",
  ISBN =         "0-06-621285-5",
  ISBN-13 =      "978-0-06-621285-2",
  bibdate =      "Wed Jun 22 18:49:36 2005",
  bibsource =    "catalogue.nla.gov.au:7090/Voyager",
  acknowledgement = ack-nhfb,
  remark =       "Includes bibliographical references and index.",
  subject =      "Natural disasters; Indonesia; Krakatoa; Social
                 aspects; Volcanoes; Indonesia; Krakatoa; Krakatoa
                 (Indonesia); Eruption, 1883",
  usmarc-019 =   "019 1 $a 24669279",
  usmarc-043 =   "043 $a a-io---",
  usmarc-250 =   "250 $a 1st U.S. ed.",
  usmarc-984 =   "984 $a ANL $c YY 551.2109598 W759",
}

@Book{Winchester:2003:MES,
  author =       "Simon Winchester",
  title =        "The meaning of everything: the story of the Oxford
                 English Dictionary",
  publisher =    "Oxford University Press",
  address =      "Oxford",
  pages =        "xxv + 260",
  year =         "2003",
  ISBN =         "0-19-860702-4 (hbk.), 0-19-860702-4 (hbk.)",
  ISBN-13 =      "978-0-19-860702-1 (hbk.), 978-0-19-860702-1 (hbk.)",
  bibdate =      "Wed Jun 22 18:49:36 2005",
  bibsource =    "catalogue.nla.gov.au:7090/Voyager",
  price =        "No price",
  acknowledgement = ack-nhfb,
  remark =       "Includes ndex.",
  subject =      "Oxford English dictionary; Lexicology; History",
  usmarc-019 =   "019 1 $a 25073662",
}\fP\s+2
.fi
.\" ====================================================================
.SH "SEARCHING THE NATIONAL LIBRARY OF POLAND"
The Polish language uses 22 accented letters that are not available in
7-bit ASCII or its 8-bit ISO 8859-1 extension used for most Western
European languages.  The Z39.50 output from the National Library of
Poland uses the ISO 6937-2 character set, which is described in a
character map available on the Web at
.RS
.nf
\fCftp://dkuug.dk/i18n/charmaps/117\fP
.fi
.RE
.B cattobib
handles translation to \*(Te\& of just the parts of that character set
that are needed for the Polish accented letters.  Input search strings
are, however, not in any standard encoding, but instead require an
awkward and idiosyncratic representation of the 22 accented letters:
.RS
.nf
\&\fC{834}A          LATIN CAPITAL LETTER A WITH ACUTE
{834}C          LATIN CAPITAL LETTER C WITH ACUTE
{834}E          LATIN CAPITAL LETTER E WITH ACUTE
{834}N          LATIN CAPITAL LETTER N WITH ACUTE
{834}O          LATIN CAPITAL LETTER O WITH ACUTE
{834}S          LATIN CAPITAL LETTER S WITH ACUTE
{834}Z          LATIN CAPITAL LETTER Z WITH ACUTE
{834}a          LATIN SMALL LETTER A WITH ACUTE
{834}c          LATIN SMALL LETTER C WITH ACUTE
{834}e          LATIN SMALL LETTER E WITH ACUTE
{834}n          LATIN SMALL LETTER N WITH ACUTE
{834}o          LATIN SMALL LETTER O WITH ACUTE
{834}s          LATIN SMALL LETTER S WITH ACUTE
{834}z          LATIN SMALL LETTER Z WITH ACUTE
{839}Z          LATIN CAPITAL LETTER Z WITH DOT ABOVE
{839}z          LATIN SMALL LETTER Z WITH DOT ABOVE
{846}A          LATIN CAPITAL LETTER A WITH OGONEK
{846}E          LATIN CAPITAL LETTER E WITH OGONEK
{846}a          LATIN SMALL LETTER A WITH OGONEK
{846}e          LATIN SMALL LETTER E WITH OGONEK
{888}           LATIN CAPITAL LETTER L WITH STROKE
{888}           LATIN SMALL LETTER L WITH STROKE\fP
.fi
.RE
Notice that the
.I same
input encoding is used for both lowercase and uppercase l-with-stroke.
The prefix \fC{834}\fP represents the acute accent, \fC{839}\fP the
dot accent, and \fC{846}\fP the ogonek (a hook accent attached near
the lower right corner of the letter).  Pictures of all of these
accented letters are available on the Web at
.RS
.nf
\fChttp://www.eki.ee/letter/chardata.cgi?lang=pl+Polish&script=latin\fP
.fi
.RE
.PP
Thus, to search for the author name represented in \&\*(Te\& as
\fCBie{\e'n}\fP, use the command
.RS
.nf
\&\fCcattobib --server pl --author "Bie{834}n"\fP
.fi
.RE
For the title represented in \*(Te\& as \fCWi{\ek{e}}{\e'z}niowie Moskwy\fP,
use the command
.RS
.nf
\&\fCcattobib --server pl --title "Wi{846}e{834}zniowie Moskwy"\fP
.fi
.RE
It would of course be much easier for users to allow matches of
unaccented letters with accented ones, but that feature is not
supported by the library catalog Z39.50 server.  Instead,
.B cattobib
provides a convenient alternative: \&\*(Te\& markup for the Polish
accented letters is silently translated to the form needed for the
National Library of Poland.  You can then write the sample search
commands as:
.RS
.nf
\&\fCcattobib --server pl --author "Bie{\e'n}"\fP
\&\fCcattobib --server pl --title "Wi{\ek{e}}{\e'z}niowie Moskwy"\fP
.fi
.RE
Outer braces surrounding accented letters may be omitted: both
\fC{\ek{a}}\fP and \fC\ek{a}\fP are recognized, as are \fC{\e'z}\fP,
\fC\e'z\fP, \fC{\e.z}\fP, \fC\e.z\fP, and so on.
.\" ====================================================================
.SH BUGS
No matter which server is selected, library-catalog data tends to be
rife with errors like these:
.RS
.TP  \w'\(bu'u+1n
\(bu
completely wrong author lists;
.TP
\(bu
duplicated records, sometimes with minor variations;
.TP
\(bu
faulty title capitalization;
.TP
\(bu
incomplete, inaccurate, or missing page numbers;
.TP
\(bu
incorrect author order;
.TP
\(bu
mangled and missing accents;
.TP
\(bu
off-by-one copyright years;
.TP
\(bu
truncated author lists and titles;
.TP
\(bu
\&.\|.\|.
.RE
.PP
The best advice to the user is to search three or more catalogs for
the same data, and then merge the results, using a majority vote to
resolve discrepancies.
.PP
When multiple catalogs provide the same data, it may indicate that the
data are likely to be reliable. However, the user is warned that
libraries around the world share cataloging data, so there may not be
as much data independence as might appear from geographically-distant
catalogs.
.PP
While the conversion of USMARC and SUTRS markup to \*(Bi\& works
reasonably well, there are many catalog record types that are not
converted.  When they are known not to be useful in \*(Bi\& entries,
they are silently discarded.  Otherwise,
.B cattobib
preserves them as additional key/value pairs, such as the
.I usmarc-nnn
keys in the \*(Bi\& output in the
.B EXAMPLES
section, or else complains about them in diagnostic messages.
.PP
.B cattobib
produces only \*(Bi\& \fC@Book{.\|.\|.}\fP entries, even for
conference proceedings, for which a \fC@Proceedings{.\|.\|.}\fP entry
is required.  Library catalog information often does not distinguish
between these document types, so the user must convert such entries.
.PP
A certain amount of manual cleanup of the \*(Bi\& output is almost
always necessary.
.\" ====================================================================
.SH "ENVIRONMENT VARIABLES"
.TP \w'TESTSHRLIBDIR'+2n
.B TESTSHRLIBDIR
Directory where format-conversion software is stored.  This variable
is primarily intended for the installation-time validation test suite,
but can also be used for testing alternate versions of the software.
.\"-----------------------------------------------
.TP
.B TMPDIR
Directory where temporary files are stored (default:
.IR /tmp ).
.\" ====================================================================
.SH "SEE ALSO"
.BR bibclean (1),
.BR biblabel (1),
.BR biborder (1),
.BR bibsort (1),
.BR bibtex (1),
.BR citesub (1),
.BR yaz-client (1).
.\" ====================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe
University of Utah
Department of Mathematics, 110 LCB
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP, \fCbeebe@computer.org\fP
WWW URL: \fChttp://www.math.utah.edu/~beebe\fP
.fi
.\" =============================[The End]==============================
